//
//  ViewController.swift
//  kantanApp
//  ofuji
//

import UIKit

class ViewController: UIViewController {

    @IBOutlet weak var backButton: UIButton!
    @IBOutlet weak var actionButton: UIButton!
    @IBOutlet weak var shereButton: UIButton!
    @IBOutlet weak var imageView: UIImageView!
    //テキストを表示するラベル。処理ボタンで更新しています。
    @IBOutlet weak var titleLabel: UILabel!
    
    let imageNames: [String] = [
        "0_dai_kichi",
        "1_cyu_kchi",
        "2_syou_kichi",
        "3_sue_kichi",
        "4_kyou",
        "5_daikyou",
    ]
    
    let messages:[String] = [
        "大吉です！\nおめでとうございます！",
        "中吉です。\n幸先の良いスタートですね",
        "小吉です。\n小さな幸せを大切にしたいですね。",
        "末吉です。\n良いことがある予感♩",
        "凶です。\nこんな日もありますね",
        "大凶です。\nこういう時こそ気を引きしめて行きましょう"
    ]
    
    override func viewDidLoad() {
        super.viewDidLoad()
        // 画面がロードされた後の処理を書きます。
        //背景に敷き詰める画像の読み込み
        if let bgImage = UIImage(named: "bg_ptn") {
            self.view.backgroundColor = UIColor(patternImage:bgImage)
        }
        //ボタンの角丸を設定
        actionButton.layer.cornerRadius = 16.0
        backButton.layer.cornerRadius = 16.0
        shereButton.layer.cornerRadius = 30.0
        //最初の画面を設定
        imageView.image = UIImage(named: "myImage")
        titleLabel.text = "おみくじを引いてね！"
        backButton.isHidden = true      //バックボタン非表示
        shereButton.isHidden = true     //バシェアボタン非表示
        
    }
    //処理ボタンが押された時の処理を書きます。
    //この中身を書き換えていろいろ試して見ましょう。
    @IBAction func pushAction(_ sender: UIButton) {
                
        actionButton.isHidden = true
        UIView.animate(withDuration: 1.0, delay: 0, options: [.autoreverse], animations: {
            self.imageView.alpha = 0.0
            self.imageView.transform = self.imageView.transform.rotated(by: -1.0)
        }, completion: { _ in 
            self.imageView.transform = self.imageView.transform.rotated(by: 1.0)
            self.imageView.alpha = 0.0
            self.updateImage()
            UIView.animate(withDuration: 1.0, delay: 0, options: [.curveLinear], animations: {
                self.imageView.alpha = 1.0
            }, completion: {_ in 
                self.imageView.alpha = 1.0
            })
        })
    }
    
    @IBAction func pushBack(_ sender: UIButton) {
        //ボタンの表示状態制御
        backButton.isHidden = true      //バックボタン非表示
        shereButton.isHidden = true     //バシェアボタン非表示
        self.actionButton.isEnabled = true
        self.actionButton.isHidden = false
        self.imageView.image = UIImage(named:"myImage")
        self.titleLabel.text = "おみくじを引いてね！"
    }
    
    //シェアボタンが押された時の処理を書きます。
    @IBAction func pushShere(_ sender: UIButton) {
        shereButton.isHidden = true
        backButton.isHidden = true
        shereActivity()
    }
    
    func updateImage() {
        //乱数を取得
        let randomNumber = randomNum()
        //おみくじのテキストを更新
        titleLabel.text = messages[randomNumber]
        //おみくじの画像を更新
        imageView.image = UIImage(named: imageNames[randomNumber])
        //ボタンの表示状態制御
        backButton.isHidden = false      //バックボタン表示
        shereButton.isHidden = false     //バシェアボタン表示
        actionButton.isEnabled = false
        actionButton.isHidden = true 
    }
    //-----ランダムに数値を返す関数
    func randomNum()->Int {
        //メッセージの配列の数の範囲内で乱数を生成
        let a = Int(arc4random_uniform(UInt32(messages.count)))
        //コンソールにプリント
        print(a)
        //値を返却
        return a
    }
    
    //画像やテキストをシェアする機能。
    //シェア先はメールやインストール済みのSNSアプリなどから選択できます。
    func shereActivity() {
        // 共有する項目
        let shareText = "おみくじを引いてみました！"
        let shereImage = self.view.snapshot()
        let activityItems = [shareText, shereImage as Any] as [Any]
        
        let shereActivity = UIActivityViewController(activityItems: activityItems, applicationActivities: nil)
        
        // 使用しないアクティビティタイプ
        let excludedActivityTypes = [
            UIActivityType.postToFlickr,
            UIActivityType.postToVimeo,
            UIActivityType.saveToCameraRoll,
            UIActivityType.assignToContact
        ]
        
        shereActivity.excludedActivityTypes = excludedActivityTypes
        
        shereActivity.completionWithItemsHandler = { (activityType, completed, returnedItems, error) in
            
            let completedString = completed ? "Completed" : "Cancelled"
            if let Activity = activityType?.rawValue {
                let operationFinishMessage = "Activity--type---\(Activity)::;\(completedString)"
                print("\(operationFinishMessage)")
            }
            self.dismiss(animated: true, completion: nil)
        }
        
        self.shereButton.isHidden = false
        self.backButton.isHidden = false
        // UIActivityViewControllerを表示
        
        //iPad対策
        if UIDevice.current.userInterfaceIdiom == .pad {
            shereActivity.popoverPresentationController?.sourceView = self.view
            shereActivity.popoverPresentationController?.sourceRect = CGRect(x: self.view.bounds.size.width / 2.0,y:  self.view.bounds.size.height / 2.0,width: 1.0,height: 1.0)
        }
        present(shereActivity, animated: true, completion: nil)
        
    }
    

}

